layouttools.set_line_breaks_by_line_duration_ge
===============================================

.. autofunction:: abjad.tools.layouttools.set_line_breaks_by_line_duration_ge.set_line_breaks_by_line_duration_ge
